# -*- coding: utf8 -*
from __future__ import unicode_literals

import copy
import datetime

from driverng import Worklist

parser_class = "sp1000i"


def test_order(self):
    worklist = copy.deepcopy(self.order_worklist)
    worklist.samples[0].results.add(code="HCT", value="438")
    worklist.samples[0].results.add(code="WBC", value="3,42")
    worklist.samples[0].results.add(code="RBC", value="4.73")
    result = self.order(worklist=worklist)
    expected = """
    H|\\^&|||||||||||E1394-97|20130715141912
    P|1
    O|1|^^         123456^C||SMEAR^438^342^473^1^0^0||20130513114242|||||N||||||||||||||Q
    C|1||      036666666^           NYME^20130513114242
    L|1|N
    """
    assert result == expected


def test_result(self):
    result = self.decode(
        """
    H|\\^&|||SP-1000i^00-12001^SP-1^^^^04303413||||||||E1394-97|20050324210847
    P|1
    O|1|| 1^01^1234^C|SMEAR^0500^^^2^1^2||20050324213040|||||N||||||||||||||F
    R|1|^^^^STAIN|OK|||||||||20050324213047
    L|1|N"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "sample_id": "1234",
                "type": "patient",
                "rack": "1-01",
                "results": [
                    {
                        "code": "STAIN",
                        "value": "OK",
                        "date": datetime.datetime(2005, 3, 24, 21, 30, 47),
                    }
                ],
            }
        ],
    }
    assert result == expected


def test_query(self):
    result = self.decode(
        """
    H|\\^&|||SP-1000i^00-12001^SP-1^^^^04303413||||||||E1394-97|20050324100447
    Q|1| 1^01^ 1234^B||||20050324214154||||O||
    L|1|N"""
    )
    expected = {
        "context": "query",
        "samples": [{"sample_id": "1234", "type": "patient"}],
    }
    assert result == expected


def test_void_order(self):
    result = self.order(
        worklist=Worklist(context="order"),
        context={
            "query": self.parse(
                """
    H|\\^&|||SP-1000i^00-12001^SP-1^^^^04303413||||||||E1394-97|20050324100447
    Q|1| 1^01^ 1234^B||||20050324214154||||O||
    L|1|N"""
            )
        },
    )
    expected = """
    H|\\^&|||||||||||E1394-97|20130715141912
    P|1
    O|1| 1^01^ 1234^C||SMEAR^0^0^0^0^0^0||20130715141912|||||N||||||||||||||Q
    C|1
    L|1|N"""
    assert result == expected
