# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

parser_class = "tango"


def test_queries(self):
    result = self.decode(
        """
    H|\\^&|||Tango|||||EuropMedica|||1|20130430091422
    Q|1|c506130508\\c505130508\\c504130508\\c503130508\\c502130508||ALL||||||||O
    L|1|N"""
    )
    expected = {
        "context": "query",
        "samples": [
            {"sample_id": "c506130508", "type": "patient"},
            {"sample_id": "c505130508", "type": "patient"},
            {"sample_id": "c504130508", "type": "patient"},
            {"sample_id": "c503130508", "type": "patient"},
            {"sample_id": "c502130508", "type": "patient"},
        ],
    }
    assert result == expected


def test_results(self):
    date = datetime.datetime(2013, 4, 29, 19, 21, 12)
    result = self.decode(
        """
    H|\\^&|||Tango|||||EuropMedica|||1|20130429192228
    P|1||03042900113151||CHEKAOUI^Dahbia||19580202|F
    O|1|1029067322||^^^ABS3|||||||||||||||||||||F
    R|1|^^^ABS3^^AB0|0|||||F||cf||20130429192112|Tango
    R|2|^^^ABS3^^RhF|pos|||||F||cf||20130429192112|Tango
    R|3|^^^ABS3^^RhS|ccD.ee|||||F||cf||20130429192112|Tango
    R|4|^^^ABS3^^Kell|pos|||||F||cf||20130429192112|Tango
    R|5|^^^ABS3^^AS|neg|||||F||cf||20130429192112|Tango
    L|1|N"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "sample_id": "1029067322",
                "type": "patient",
                "results": [
                    {"date": date, "value": "0", "code": "ABS3AB0", "operator": "cf"},
                    {"date": date, "value": "pos", "code": "ABS3RhF", "operator": "cf"},
                    {"date": date, "value": "c", "code": "ABS3RhS0", "operator": "cf"},
                    {"date": date, "value": "c", "code": "ABS3RhS1", "operator": "cf"},
                    {"date": date, "value": "D", "code": "ABS3RhS2", "operator": "cf"},
                    {"date": date, "value": ".", "code": "ABS3RhS3", "operator": "cf"},
                    {"date": date, "value": "e", "code": "ABS3RhS4", "operator": "cf"},
                    {"date": date, "value": "e", "code": "ABS3RhS5", "operator": "cf"},
                    {
                        "date": date,
                        "value": "pos",
                        "code": "ABS3Kell",
                        "operator": "cf",
                    },
                    {"date": date, "value": "neg", "code": "ABS3AS", "operator": "cf"},
                ],
            }
        ],
    }
    assert result == expected


def test_order(self):
    result = self.order()
    expected = """
        H|\\^&|||||||||||1|20130715141912
        P|1||036666666||NYME^ANO|NJF|20110513|F
        O|1|123456||^^^A\\^^^B|N||||||||||||||||||||O
        L|1|N
    """
    assert result == expected
